@@ -52,7 +52,7 @@ class MateParser(object):
         tag_file = NamedTemporaryFile()
         self._run_cmd(['java', '-Xmx2G', '-cp', class_path,
                        'is2.tag.Tagger',  '-model', self.tag_model,
-                       '-test', in_filename,
+                       '-test', lemma_file.name,
                        '-out', tag_file.name])
 
         # Parser
